summary.tda: Summarizing discriminant analysis results from function "tda"

View source: R/summary.tda.R

summary.tdaR Documentation

Summarizing discriminant analysis results from function 'tda'

Description

Summary for the results of discriminant analysis obtained by function 'tda'

Usage

## S3 method for class 'tda'
summary(object, ...)
## S3 method for class 'summary.tda'
print(x, ...)

Arguments

object

An object of class 'tda' produced by function 'tda'

x

An object of class 'summary.tda' obtained by function 'summary.tda'

...

Additional arguments that are passed to or from other methods

Value

Function 'summary.tda' calculates and returns a list of summary statistics for the model estimated by function 'tda'

See Also

tda

Examples

set.seed(123)
model <- tda(x = iris[,1:4], ID = iris$Species,max_k = 2, trans = FALSE)
summary(model)

transDA documentation built on Sept. 9, 2025, 5:53 p.m.