| transDA-package | R Documentation |
Transformation and mixture discriminant analysis.
| Package: | transDA |
| Type: | Package |
| Version: | 1.0.2 |
| Date: | 2025-9-4 |
| License: | GPL (>= 2) |
| LazyLoad: | no |
Function 'tda' is the main function of the package that allows running traditional linear and quadratic discriminant procedures as well as more flexible options such as mixture discriminant analysis, transformation discriminant analysis, or their combination.
Function 'predict.tda' makes classification predictions for a provided testing data set.
Jing Li and Yana Melnykov
Maintainer: Jing Li jli178@crimson.ua.edu
Hastie, T., & Tibshirani, R. (1996). Discriminant analysis by Gaussian mixtures. Journal of the Royal Statistical Society Series B: Statistical Methodology, 58(1), 155-176.
Jing Li & Yana Melnykov (2025) Transformation Discriminant Analysis. (under review)
tda,
predict.tda
set.seed(123)
data(iris)
MDA <- tda(x = iris[,1:4], ID = iris$Species, max_k = 2, trans = FALSE)
summary(MDA)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.