| summary.tda | R Documentation |
'tda'
Summary for the results of discriminant analysis obtained by function 'tda'
## S3 method for class 'tda'
summary(object, ...)
## S3 method for class 'summary.tda'
print(x, ...)
object |
An object of class |
x |
An object of class |
... |
Additional arguments that are passed to or from other methods |
Function 'summary.tda' calculates and returns a list of summary statistics for the model estimated by function 'tda'
tda
set.seed(123)
model <- tda(x = iris[,1:4], ID = iris$Species,max_k = 2, trans = FALSE)
summary(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.